fnss.netconfig.buffers.get_buffer_sizes — FNSS 0.3.2 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.3.2 documentation »
- API Reference »
- Functions »

# fnss.netconfig.buffers.get_buffer_sizes

`get_buffer_sizes`(topology)

  Returns all the buffer sizes.

  Parameters : | topology : Topology or DirectedTopology
  Returns : | buffer_sizes : dict Dictionary of buffer sizes keyed by (u, v) tuple. The key (u, v) represents a network interface where u is the node on which the interface is located and (u, v) is the link to which the buffer flushes

  Examples

      >>> import fnss
      >>> topology = fnss.Topology()
      >>> topology.add_path([1, 2, 3])
      >>> fnss.set_buffer_sizes_constant(topology, buffer_size=10)
      >>> buffer = fnss.get_buffer_sizes(topology)
      >>> buffer[(1,2)]
      10

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.3.2 documentation »
- API Reference »
- Functions »